@@ -30,6 +30,20 @@ def test_edges(comm):
     assert_array_equal(partition.i_edges[0], [0, 2, 4, 4])
     assert_array_equal(partition.i_edges[1], [0, 4])
 
+    assert_array_equal(partition.o_edges[1], [0, 2, 4, 4])
+    assert_array_equal(partition.o_edges[0], [0, 4])
+
+@MPITest(3)
+def test_nino(comm):
+    procmesh = pfft.ProcMesh(np=[comm.size,], comm=comm)
+
+    partition = pfft.Partition(pfft.Type.PFFT_C2C,
+            [4, 8], procmesh,
+            pfft.Flags.PFFT_TRANSPOSED_OUT)
+
+    assert_array_equal(partition.ni, [4, 8])
+    assert_array_equal(partition.no, [4, 8])
+
 @MPITest(1)
 def test_transposed(comm):
     procmesh = pfft.ProcMesh(np=[1,], comm=comm)
